@@ -22,12 +22,12 @@ def display(filename, display_length, norm_min_percent, norm_max_percent):
     img = img.astype(np.float32)
     img = img[0:display_length, :, :]
     img = normalize(img, norm_min_percent, norm_max_percent)
-    cv2.namedWindow('video')
+    cv2.namedWindow('Raw video')
     for i in range(display_length):
         tempimg = img[i, :, :]
-        cv2.imshow('video', tempimg)
+        cv2.imshow('Raw video', tempimg)
         cv2.waitKey(33)
-    cv2.destroyWindow('video')
+    cv2.destroyWindow('Raw video')
 
 
 def test_img_display(img, display_length, norm_min_percent, norm_max_percent):
@@ -42,9 +42,9 @@ def test_img_display(img, display_length, norm_min_percent, norm_max_percent):
     """
     img = img[50:display_length-50, :, :] # display the middle frames
     img = normalize(img, norm_min_percent, norm_max_percent)
-    cv2.namedWindow('video')
+    cv2.namedWindow('Denoised video')
     for i in range(display_length - 100):
         tempimg = img[i, :, :]
-        cv2.imshow('video', tempimg)
+        cv2.imshow('Denoised video', tempimg)
         cv2.waitKey(33)
-    cv2.destroyWindow('video')
+    cv2.destroyWindow('Denoised video')
