@@ -196,9 +196,11 @@ class testing_class():
         Pytorch testing workflow
 
         """
+        pth_count=0
         for pth_index in range(len(self.model_list)):
             aaa = self.model_list[pth_index]
             if '.pth' in aaa:
+                pth_count=pth_count+1
                 pth_name = self.model_list[pth_index]
                 output_path_name = self.output_path + '//' + pth_name.replace('.pth', '')
                 if not os.path.exists(output_path_name):
@@ -246,7 +248,7 @@ class testing_class():
                             print(
                                 '\r[Model %d/%d, %s] [Stack %d/%d, %s] [Patch %d/%d] [Time Cost: %.0d s] [ETA: %s s]     '
                                 % (
-                                    pth_index + 1,
+                                    pth_count,
                                     self.model_list_length,
                                     pth_name,
                                     N + 1,
@@ -299,7 +301,7 @@ class testing_class():
 
                     # Normalize and display inference image
                     if (self.visualize_images_per_epoch):
-                        print('Displaying the denoise file ----->')
+                        print('Displaying the denoised file ----->')
                         display_length = 200
                         test_img_display(output_img, display_length=display_length, norm_min_percent=1,
                                          norm_max_percent=99)
