@@ -186,7 +186,7 @@ class training_class():
             self.whole_x = noise_im.shape[2]
             self.whole_y = noise_im.shape[1]
             self.whole_t = noise_im.shape[0]
-            print('Noise images shape -----> ', noise_im.shape)
+            print('Noise image shape -----> ', noise_im.shape)
             # Calculate real gap_t
             self.get_gap_t()
             # No preprocessing
@@ -309,7 +309,7 @@ class training_class():
                 if iteration % 1 == 0:
                     time_end = time.time()
                     print(
-                        '\r[Epoch %d/%d] [Batch %d/%d] [Total loss: %.2f, L1 Loss: %.2f, L2 Loss: %.2f] [ETA: %s] [Time cost: %.2d s]   '
+                        '\r[Epoch %d/%d] [Batch %d/%d] [Total loss: %.2f, L1 Loss: %.2f, L2 Loss: %.2f] [ETA: %s] [Time cost: %.2d s]     '
                         % (
                             epoch + 1,
                             self.n_epochs,
@@ -322,16 +322,17 @@ class training_class():
                             time_end - time_start
                         ), end=' ')
 
-                if (iteration + 1) % len(trainloader) == 0:
-                    print('\n', end=' ')
+
 
                 if (iteration + 1) % (len(trainloader)) == 0:
+                    print('\n', end=' ')
                     # Save model at the end of every epoch
                     self.save_model(epoch, iteration)
                     # Start inference using the denoise model at the end of every epoch (optional)
                     if (self.visualize_images_per_epoch | self.save_test_images_per_epoch):
-                        print('Testing epoch {} model on the first noisy file ----->'.format(epoch + 1))
+                        print('Testing model of epoch {} on the first noisy file ----->'.format(epoch + 1))
                         self.test(epoch, iteration)
+                        print('\n', end=' ')
         print('Train finished. Save all models to disk.')
 
     def save_model(self, epoch, iteration):
@@ -432,7 +433,7 @@ class training_class():
 
         # Normalize and display inference image
         if (self.visualize_images_per_epoch):
-            print('Displaying the first denoise file ----->')
+            print('Displaying the first denoised file ----->')
             display_length = self.test_datasize
             test_img_display(output_img, display_length=display_length, norm_min_percent=1, norm_max_percent=98)
 
